@@ -184,6 +184,8 @@ void MainWindow::setGui()
         ui->checkBoxStartup->setChecked(true);
     }
     ui->textSearch->setFocus();
+    ui->pushCancel->setDefault(true); // Otherwise some other button might be default
+    ui->pushCancel->setDefault(false);
 }
 
 void MainWindow::btn_clicked()
@@ -271,15 +273,11 @@ QString MainWindow::getDesktopFileName(const QString &app_name)
 QStringList MainWindow::getDesktopFileInfo(const QString &file_name)
 {
     QStringList app_info;
-
     QString name;
     QString comment;
     QString exec;
     QString icon_name;
     QString terminal;
-    QLocale locale;
-    QString lang = locale.bcp47Name();
-
     QRegularExpression re;
     re.setPatternOptions(QRegularExpression::MultilineOption);
 
@@ -295,30 +293,32 @@ QStringList MainWindow::getDesktopFileInfo(const QString &file_name)
 
     const QString text = file.readAll();
     file.close();
-
     if (lang != QLatin1String("en")) {
         re.setPattern(QStringLiteral("^Name\\[") + lang + QStringLiteral("\\]=(.*)$"));
-        name = re.match(text).captured(1);
+        QRegularExpressionMatch nameMatch = re.match(text);
+        if (nameMatch.hasMatch())
+            name = nameMatch.captured(1);
         re.setPattern(QStringLiteral("^Comment\\[") + lang + QStringLiteral("\\]=(.*)$"));
-        comment = re.match(text).captured(1);
+        QRegularExpressionMatch commentMatch = re.match(text);
+        if (commentMatch.hasMatch())
+            comment = commentMatch.captured(1);
     }
-    if (lang == QLatin1String("pt") && name.isEmpty()) { // Brazilian if Portuguese and name empty
-        re.setPattern(QStringLiteral("^Name\\[pt_BR\\]=(.*)$"));
-        name = re.match(text).captured(1);
-    }
-    if (lang == QLatin1String("pt") && comment.isEmpty()) { // Brazilian if Portuguese and comment empty
-        re.setPattern(QStringLiteral("^Comment\\[pt_BR\\]=(.*)$"));
-        comment = re.match(text).captured(1);
-    }
-    if (name.isEmpty()) { // backup if Name is not translated
+    // Fallback if Name is not translated
+    if (name.isEmpty()) {
         re.setPattern(QStringLiteral("^Name=(.*)$"));
-        name = re.match(text).captured(1);
-        name = name.remove(QRegularExpression(
-            QStringLiteral("^MX "))); // remove MX from begining of the program name (most of the MX Linux apps)
+        QRegularExpressionMatch nameFallbackMatch = re.match(text);
+        if (nameFallbackMatch.hasMatch()) {
+            name = nameFallbackMatch.captured(1);
+            name = name.remove(QRegularExpression(
+                QStringLiteral("^MX "))); // remove MX from begining of the program name (most of the MX Linux apps)
+        }
     }
-    if (comment.isEmpty()) { // backup if Comment is not translated
+    // Fallback if Comment is not translated
+    if (comment.isEmpty()) {
         re.setPattern(QStringLiteral("^Comment=(.*)$"));
-        comment = re.match(text).captured(1);
+        QRegularExpressionMatch commentFallbackMatch = re.match(text);
+        if (commentFallbackMatch.hasMatch())
+            comment = commentFallbackMatch.captured(1);
     }
     re.setPattern(QStringLiteral("^Exec=(.*)$"));
     exec = re.match(text).captured(1);
@@ -417,22 +417,14 @@ void MainWindow::addButtons(const QMultiMap<QString, QStringList> &map)
 
 void MainWindow::processLine(const QString &line)
 {
-    if (line.startsWith(QLatin1String("#")) || line.isEmpty()) // filter out comment and empty lines
-        return;
-
-    const QStringList line_list = line.split(QStringLiteral("="));
-    const QString key = line_list.first().trimmed();
+    const QStringList tokens = line.split(QStringLiteral("="));
+    const QString key = tokens.first().trimmed();
     QString value;
-    if (line_list.size() > 1) {
-        value = line_list.at(1).trimmed();
+    if (tokens.size() > 1) {
+        value = tokens.at(1).trimmed();
         value.remove(QLatin1Char('"'));
     }
-
-    if (key.toLower() == QLatin1String("name")) {
-        this->setWindowTitle(value);
-    } else if (key.toLower() == QLatin1String("comment")) {
-        ui->commentLabel->setText(value);
-    } else if (key.toLower() == QLatin1String("category")) {
+    if (key.toLower() == QLatin1String("category")) {
         categories.append(value);
     } else if (key.toLower() == QLatin1String("theme")) {
         icon_theme = value;
@@ -442,7 +434,7 @@ void MainWindow::processLine(const QString &line)
         if (!desktop_file.isEmpty()) {
             QStringList info = getDesktopFileInfo(desktop_file);
             if (list.size() > 1) { // check if root or alias flag present
-                info << ((list.contains(QLatin1String("root"))) ? QStringLiteral("true") : QStringLiteral("false"));
+                info << (list.contains(QLatin1String("root")) ? QStringLiteral("true") : QStringLiteral("false"));
                 if (list.contains(QLatin1String("alias"))) {
                     QString str;
                     for (auto it = list.lastIndexOf(QStringLiteral("alias")); it + 1 < list.size(); ++it)
@@ -452,7 +444,6 @@ void MainWindow::processLine(const QString &line)
             } else {
                 info << QStringLiteral("false");
             }
-
             category_map.insert(categories.constLast(), info);
         }
     }
@@ -475,11 +466,49 @@ void MainWindow::readFile(const QString &file_name)
                               tr("Could not open file: ") + file_name + "\n" + tr("Application will close."));
         exit(EXIT_FAILURE);
     }
-
-    for (QTextStream in(&file); !in.atEnd();)
-        processLine(in.readLine());
+    const QString text = file.readAll();
     file.close();
 
+    QString name;
+    QString comment;
+    QRegularExpression re;
+    re.setPatternOptions(QRegularExpression::MultilineOption);
+    if (lang != QLatin1String("en")) {
+        re.setPattern(QStringLiteral("^Name\\[") + lang + QStringLiteral("\\]=(.*)$"));
+        QRegularExpressionMatch nameMatch = re.match(text);
+        if (nameMatch.hasMatch())
+            name = nameMatch.captured(1);
+        re.setPattern(QStringLiteral("^Comment\\[") + lang + QStringLiteral("\\]=(.*)$"));
+        QRegularExpressionMatch commentMatch = re.match(text);
+        if (commentMatch.hasMatch())
+            comment = commentMatch.captured(1);
+    }
+    // Fallback if Name is not translated
+    if (name.isEmpty()) {
+        re.setPattern(QStringLiteral("^Name=(.*)$"));
+        QRegularExpressionMatch nameFallbackMatch = re.match(text);
+        if (nameFallbackMatch.hasMatch())
+            name = nameFallbackMatch.captured(1);
+    }
+    // Fallback if Comment is not translated
+    if (comment.isEmpty()) {
+        re.setPattern(QStringLiteral("^Comment=(.*)$"));
+        QRegularExpressionMatch commentFallbackMatch = re.match(text);
+        if (commentFallbackMatch.hasMatch())
+            comment = commentFallbackMatch.captured(1);
+    }
+    this->setWindowTitle(name);
+    ui->commentLabel->setText(comment);
+
+    auto lines = text.split("\n");
+    for (const QString &line : lines) {
+        if (line.startsWith(QLatin1String("name"), Qt::CaseInsensitive)
+            || line.startsWith(QLatin1String("comment"), Qt::CaseInsensitive) || line.isEmpty()
+            || line.startsWith(QLatin1String("#")))
+            continue;
+        processLine(line);
+    }
+
     // Reverse map
     QMultiMap<QString, QStringList> map;
     for (auto i = category_map.constBegin(); i != category_map.constEnd(); ++i)
@@ -601,24 +630,25 @@ void MainWindow::pushEdit_clicked()
         if (editor.isEmpty()) // use nano as backup editor
             editor = "nano";
     }
-    // Editors that need to run as normal user
-    if (getuid() == 0
-        && (QRegularExpression("(kate|kwrite|featherpad)$").match(editor).hasMatch()
-            || QRegularExpression("atom\\.desktop$").match(desktop_file).hasMatch()))
-        editor.push_front("pkexec --user $(logname) env DISPLAY=$DISPLAY XAUTHORITY=$XAUTHORITY ");
 
-    QString cmd = editor + " " + file_name;
+    bool isRoot = (getuid() == 0);
+    bool isEditorThatElevates = QRegularExpression("(kate|kwrite|featherpad)$").match(editor).hasMatch();
+    bool isAtom = QRegularExpression("atom\\.desktop$").match(desktop_file).hasMatch();
+    bool isCliEditor = QRegularExpression("nano|vi|vim|nvim|micro|emacs").match(editor).hasMatch();
 
-    // Handle CLI editors
-    if (QRegularExpression("nano|vi|vim|nvim|micro|emacs").match(editor).hasMatch()) {
-        QString term_env = "env DISPLAY=$DISPLAY XAUTHORITY=$XAUTHORITY x-terminal-emulator -e ";
-        cmd.push_front(term_env);
-    }
+    QStringList editorCommands;
+    if (!QFileInfo(file_name).isWritable() && !isEditorThatElevates && !isAtom)
+        editorCommands << "pkexec";
 
-    // If we need to run as root (with the exception of the listed editors)
-    if (!QFileInfo(file_name).isWritable() && !QRegularExpression("(kate|kwrite|featherpad)$").match(editor).hasMatch()
-        && !QRegularExpression("atom\\.desktop$").match(desktop_file).hasMatch())
-        cmd.push_front("pkexec ");
+    if (isRoot && (isEditorThatElevates || isAtom))
+        editorCommands << "pkexec --user $(logname)";
+
+    editorCommands << "env DISPLAY=$DISPLAY XAUTHORITY=$XAUTHORITY";
+
+    if (isCliEditor)
+        editorCommands << "x-terminal-emulator -e";
+
+    QString cmd = editorCommands.join(" ") + " " + editor.toUtf8() + " " + file_name;
     system(cmd.toUtf8());
     readFile(file_name);
     setGui();
